@@ -298,6 +298,7 @@ typedef struct {
 #define DEFAULT_BASE 10
 #define DEFAULT_SUBDECKS 3
 #define DEFAULT_SUBBEADS 4
+#define DEFAULT_DECIMAL_POSITION 2
 #define DEFAULT_SHIFT_PERCENT 2
 #define DEFAULT_SHIFT_ANOMALY 2
 #define DEFAULT_GROUP_SIZE 3
@@ -331,7 +332,7 @@ typedef struct {
 #define QUARTER_PERCENTS 4
 #define TWELFTHS 12
 #define EIGHTHS 8
-#define TEACH_STRING0 "Enter calculation X+Y, X-Y, X*Y, X/Y, or Xv where X positive and result positive."
+#define TEACH_STRING0 "Enter calculation X+Y, X-Y, X*Y, X/Y, Xv, or Xu where X positive and result positive."
 #define TEACH_STRING1 "Press enter to go through calculation steps."
 
 typedef struct _AbacusRec *AbacusWidget;
