@@ -700,7 +700,7 @@ newStack(void)
 	if (!(plate = (Term *) malloc(sizeof(Term))))
 		return False;
 	plate->previous = NULL;
-	term = plate->previous;
+	term = plate;
 	return True;
 }
 #endif
@@ -1170,6 +1170,28 @@ zeroFractionalPart(char * buf)
 		}
 }
 
+char *strAddChar(char *buf, char c)
+{
+	char *s;
+
+	s = buf;
+	s = s + strlen(buf); /* the position to write */
+	*s = c; /* this should be on the place where the null char first was. */
+	s++;
+	*s = '\0'; /* add a new null string */
+	return buf;
+}
+
+char *strAddInt(char *buf, int value)
+{
+	char *s;
+
+	s = buf;
+	s = s + strlen(buf); /* the position to write */
+	(void) sprintf(s, "%d", value); /* always base 10 */
+	return buf;
+}
+
 static void
 convertStringBases(char *sb, char *buf, int displayBase, int base) {
 	int i;
@@ -1195,7 +1217,7 @@ convertStringBases(char *sb, char *buf, int displayBase, int base) {
 			(void) printf("ns =%s\n", numberString);
 #endif
 		} else {
-			(void) sprintf(sb, "%s%c", sb, buf[i]);
+			sb = strAddChar(sb, buf[i]);
 		}
 	}
 }
