@@ -566,7 +566,8 @@ convertString(char * buf, char * inbuf, int base, int displayBase,
 	(void) int2String(buf, intPart, displayBase, negative);
 	(void) flt2String(fltbuf, floatPart, base, displayBase,
 		decimalPointPlace, decimalPosition);
-	(void) sprintf(buf, "%s.%s", buf, fltbuf);
+	(void) strcat(buf, ".");
+	(void) strcat(buf, fltbuf);
 #ifdef DEBUG
 	(void) printf("convertString: outbuf %s\n", buf);
 #endif
@@ -825,7 +826,7 @@ void string2Group(char *buf, char *inbuf, int groupSize, char decimalPoint,
 		j++;
 	}
 	buf[j] = '\0';
-	(void) sprintf(buf, "%s%s", buf, &inbuf[len - 1]);
+	(void) strcat(buf, &inbuf[len - 1]);
 }
 
 int
