@@ -230,7 +230,7 @@ typedef struct _AbacusPart {
 	Boolean     rightToLeftAdd, rightToLeftMult;
 	int         step, carry[2], lower, upper, carryStep;
 	int         state; /* explain or carrying out operation */
-	int         reg, regCount, qDigit, qPosition;
+	int         reg, regCount, qDigit, qPosition, auxCount, primarySteps;
 	double      divisor;
 	char        op;
 	int        *intGroup;
